# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pyproject_autoflake']

package_data = \
{'': ['*']}

install_requires = \
['autoflake', 'toml>=0.10.1']

entry_points = \
{'console_scripts': ['pautoflake = pyproject_autoflake.pautoflake:main']}

setup_kwargs = {
    'name': 'pyproject-autoflake',
    'version': '0.3.0',
    'description': 'pyproject-autoflake (pautoflake), a monkey patching wrapper to connect autoflake with pyproject.toml configuration.',
    'long_description': '# pyproject-autoflake\n\n**pyproject-autoflake** (**pautoflake**), a monkey patching wrapper to connect [autoflake](https://github.com/myint/autoflake) with pyproject.toml configuration.\n\n## Motivation\n\nThe original autoflake does not support configuration files such as pyproject.toml.\nThis is slightly inconvenient for modern Python development.\n\npautoflake is a thin wrapper library that calls autoflake with a configuration read from pyproject.toml.\n\npyproject-autoflake is inspired by [pyproject-flake8](https://github.com/csachs/pyproject-flake8). Many thanks! 😉\n\n## Installation\n\n### pip\n\n```sh\npip install pyproject-autoflake\n```\n\n### poetry\n\n```sh\npoetry add -D pyproject-autoflake\n```\n\n## Usage\n\nAt first, you add `[tool.autoflake]` in your pyproject.toml.\n\n```toml\n# pyproject.toml\n\n...\n\n[tool.autoflake]\n# return error code if changes are needed\ncheck = false\n# make changes to files instead of printing diffs\nin-place = true\n# drill down directories recursively\nrecursive = true\n# exclude file/directory names that match these comma-separated globs\nexclude = "<GLOBS>"\n# by default, only unused standard library imports are removed; specify a comma-separated list of additional\n# modules/packages\nimports = "<IMPORTS>"\n# expand wildcard star imports with undefined names; this only triggers if there is only one star import in\n# the file; this is skipped if there are any uses of `__all__` or `del` in the file\nexpand-star-imports = true\n# remove all unused imports (not just those from the standard library)\nremove-all-unused-imports = true\n# exclude __init__.py when removing unused imports\nignore-init-module-imports = true\n# remove all duplicate keys in objects\nremove-duplicate-keys = true\n# remove unused variables\nremove-unused-variables = true\n# print more verbose logs (larger numbers are more verbose)\nverbose = 0\n\n...\n\n```\n\nSecond, you call **p**autoflake.\n\n```bash\npautoflake sample.py\n```\n\n## License\n\n[MIT License](./LICENSE)\n',
    'author': 'quwac',
    'author_email': '53551867+quwac@users.noreply.github.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/quwac/pyproject-autoflake',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



import os
import signal
import sys
from pathlib import Path
from typing import Dict, List, Optional, Tuple, Union

import autoflake
import toml


def _get_pyproject_toml_path(path_candidates: List[str]) -> str:
    absolute_paths: List[Path] = []
    for path_candidate in path_candidates:
        path = Path(path_candidate)
        if not path.is_absolute():
            path = Path(Path.cwd(), path_candidate)
        absolute_paths.append(path.resolve())

    for absolute_path in absolute_paths:
        dir_path = absolute_path if absolute_path.is_dir() else absolute_path.parent
        while dir_path.exists():
            pyproject_toml_path = Path(dir_path, "pyproject.toml")
            if pyproject_toml_path.exists() and pyproject_toml_path.is_file():
                return str(pyproject_toml_path)
            next_dir_path = dir_path.parent
            if next_dir_path == dir_path:
                break
            dir_path = next_dir_path

    raise ValueError("pyproject.toml not found.")


def _get_argv_from_toml(pyproject_path: Optional[str] = None) -> List[str]:
    if pyproject_path is None:
        pyproject_path = os.path.join(os.getcwd(), "pyproject.toml")
    assert (
        pyproject_path is not None and pyproject_path != "" and os.path.exists(pyproject_path)
    ), f"pyproject.toml not found. {pyproject_path}"

    with open(pyproject_path, "r") as f:
        obj = toml.load(f)

    arg_pairs: List[Tuple[str, Union[None, str, int]]] = [(sys.argv[0], None)]
    arg_name_to_index: Dict[str, int] = {}

    try:
        try:
            tool = obj["tool"]
            tool_autoflake: Dict[str, Union[str, bool, int]] = tool["autoflake"]
        except Exception as e:
            raise ValueError(f"[tool.autoflake] section not found in {pyproject_path}.") from e

        for key, value in tool_autoflake.items():
            if key is None or key == "":
                continue

            assert value is not None, f"tool.autoflake.{key} must be not null."
            type_value = type(value)
            assert (
                type_value is bool or type_value is int or type_value is str
            ), f"tool.autoflake.{key} must be bool or string, but {type_value}"
            del type_value

            if len(key) == 1:
                arg_name = f"-{key}"
            else:
                arg_name = f"--{key}"

            arg_value: Union[None, str, int] = None
            if type(value) is bool:
                if not value:
                    continue
            elif type(value) is int:
                arg_value = value
            elif type(value) is str:
                if value == "":
                    continue
                arg_value = value
            else:
                raise ValueError(f"Logic error. key={key},value={value}")

            arg_pairs.append((arg_name, arg_value))
            arg_name_to_index[arg_name] = len(arg_pairs) - 1
    except Exception:
        pass

    for arg in sys.argv[1:]:
        arg_pairs.append((arg, None))

    argv = []
    for key, value in arg_pairs:
        if value is not None:
            if type(value) is str:
                argv.append(key)
                argv.append(value)
            elif type(value) is int:
                for _ in range(value):
                    argv.append(key)
        else:
            argv.append(key)

    return argv


def main() -> int:
    try:
        signal.signal(signal.SIGPIPE, signal.SIG_DFL)
    except AttributeError:
        pass

    path_candidates = list(filter(lambda arg: not arg.startswith("-"), sys.argv[1:]))
    if len(path_candidates) == 0:
        return autoflake._main(argv=[sys.argv[0], "-h"], standard_out=sys.stdout, standard_error=sys.stderr)
    pyproject_toml = _get_pyproject_toml_path(path_candidates)
    argv = _get_argv_from_toml(pyproject_toml)

    try:
        return autoflake._main(argv=argv, standard_out=sys.stdout, standard_error=sys.stderr)
    except KeyboardInterrupt:
        return 2
